# Pytorch Keras 
It is keras like for the Pytorch.
For now, it has Fit and compile method and rest will be added later, it does not behave exactly like Keras, but we can make it so in the future.


## Installtion

Run the following to install

```python
    pip install pytorchkeras==0.0.1
```

## Usage
```python
    from PytorchKeras import PytorchKeras
```